aboutsummaryrefslogtreecommitdiff
path: root/roomserver/api/input.go
diff options
context:
space:
mode:
authorAlex Chen <Cnly@users.noreply.github.com>2019-08-24 00:55:40 +0800
committerGitHub <noreply@github.com>2019-08-24 00:55:40 +0800
commit43308d2f3f8fcf9bdb3ec55d4e679b576cc19488 (patch)
tree07ab7545bf6c113f7db41eac7d84926f52c81f74 /roomserver/api/input.go
parent5eb63f1d1eafae0111d46def5cf5bf431d2e8169 (diff)
Associate transactions with session IDs instead of device IDs (#789)
Diffstat (limited to 'roomserver/api/input.go')
-rw-r--r--roomserver/api/input.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/roomserver/api/input.go b/roomserver/api/input.go
index 2c2e27c6..9643a927 100644
--- a/roomserver/api/input.go
+++ b/roomserver/api/input.go
@@ -75,9 +75,9 @@ type InputRoomEvent struct {
}
// TransactionID contains the transaction ID sent by a client when sending an
// event, along with the ID of that device.
type TransactionID struct {
- DeviceID string `json:"device_id"`
+ SessionID int64 `json:"session_id"`
TransactionID string `json:"id"`
}
@@ -75,9 +75,9 @@ type InputRoomEvent struct {
}
// TransactionID contains the transaction ID sent by a client when sending an
-// event, along with the ID of that device.
+// event, along with the ID of the client session.
type TransactionID struct {